@@ -1,7 +1,21 @@
-#' Search for implicative rules
+#' Search for association rules
 #'
-#' Implicative rule is a rule of the form \eqn{A \Rightarrow c}{A => c},
-#' where \eqn{A} (*antecedent*) is a set of predicates and \eqn{c} (*consequent*) is a predicate.
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' Association rules identify conditions (*antecedents*) under which
+#' a specific feature (*consequent*) is present very often.
+#'
+#' \describe{
+#'   \item{Scheme:}{`A => C`\cr\cr
+#'     If condition `A` is satisfied, then the feature `C` is present very often.}
+#'   \item{Example:}{`university_edu & middle_age & IT_industry => high_income`\cr\cr
+#'     People in *middle age* with *university education* working in IT industry
+#'     have very likely a *high income*.}
+#' }
+#'
+#' Antecedent `A` is usually a set of predicates, and consequent `C` is a single
+#' predicate.
 #'
 #' For the following explanations we need a mathematical function \eqn{supp(I)}, which
 #' is defined for a set \eqn{I} of predicates as a relative frequency of rows satisfying
@@ -11,7 +25,7 @@
 #' of truth degrees of the formula `i_1 AND i_2 AND ... AND i_n`, where
 #' `AND` is a triangular norm selected by the `t_norm` argument.
 #'
-#' Implicative rules are characterized with the following quality measures.
+#' Association rules are characterized with the following quality measures.
 #'
 #' *Length* of a rule is the number of elements in the antecedent.
 #'
@@ -35,7 +49,9 @@
 #' @param disjoint an atomic vector of size equal to the number of columns of `x`
 #'      that specifies the groups of predicates: if some elements of the `disjoint`
 #'      vector are equal, then the corresponding columns of `x` will NOT be
-#'      present together in a single condition.
+#'      present together in a single condition. If `x` is prepared with
+#'      [partition()], using the [var_names()] function on `x`'s column names
+#'      is a convenient way to create the `disjoint` vector.
 #' @param min_length the minimum length, i.e., the minimum number of predicates in the
 #'      antecedent, of a rule to be generated. Value must be greater or equal to 0.
 #'       If 0, rules with empty antecedent are generated in the first place.
@@ -64,14 +80,23 @@
 #'      (Lukasiewicz t-norm).
 #' @param threads the number of threads to use for parallel computation.
 #' @param ... Further arguments, currently unused.
-#' @returns A tibble with found rules and computed quality measures.
+#' @returns A tibble with found patterns and computed quality measures.
 #' @author Michal Burda
-#' @seealso [dig()]
+#' @seealso [partition()], [var_names()], [dig()]
+#' @examples
+#' d <- partition(mtcars, .breaks = 2)
+#' dig_associations(d,
+#'                  antecedent = !starts_with("mpg"),
+#'                  consequent = starts_with("mpg"),
+#'                  min_support = 0.3,
+#'                  min_confidence = 0.8,
+#'                  measures = c("lift", "conviction"))
+#' @keywords internal
 #' @export
 dig_implications <- function(x,
                              antecedent = everything(),
                              consequent = everything(),
-                             disjoint = NULL,
+                             disjoint = var_names(colnames(x)),
                              min_length = 0L,
                              max_length = Inf,
                              min_coverage = 0,
@@ -82,125 +107,20 @@ dig_implications <- function(x,
                              t_norm = "goguen",
                              threads = 1,
                              ...) {
-    .must_be_double_scalar(min_coverage)
-    .must_be_in_range(min_coverage, c(0, 1))
+    lifecycle::deprecate_warn("1.4.0", "dig_implications()", with = "dig_associations()")
 
-    .must_be_double_scalar(min_support)
-    .must_be_in_range(min_support, c(0, 1))
-
-    .must_be_double_scalar(min_confidence)
-    .must_be_in_range(min_confidence, c(0, 1))
-
-    .must_be_flag(contingency_table)
-    .must_be_enum(measures,
-                  values = c("lift", "conviction", "added_value"),
-                  null = TRUE,
-                  multi = TRUE)
-
-    min_coverage <- max(min_coverage, min_support)
-    n <- nrow(x)
-
-    antecedent <- enquo(antecedent)
-    consequent <- enquo(consequent)
-
-    f1 <- function(condition, support) {
-        res <- support
-        names(res) <- colnames(x)[condition]
-
-        res
-    }
-
-    conseq_supports <- dig(x = x,
-                           f = f1,
-                           condition = !!consequent,
-                           min_length = 1,
-                           max_length = 1,
-                           min_support = 0.0,
-                           threads = threads)
-    conseq_supports <- unlist(conseq_supports)
-
-    basic_callback <- function(condition, sum, pp) {
-        conf <- pp / sum
-        sel <-!is.na(pp) & !is.na(conf) & conf >= min_confidence
-        selnames <- names(pp)[sel]
-        conf <- conf[sel]
-        supp <- pp[sel] / n
-        ante <- format_condition(names(condition))
-        cons <- unlist(lapply(names(conf), format_condition))
-
-        if (length(conf) <= 0) {
-            return(list(sel = logical(0), res = NULL))
-        }
-
-        list(sel = sel,
-             res =  data.frame(antecedent = ante,
-                               consequent = cons,
-                               support = supp,
-                               confidence = conf,
-                               coverage = sum / n,
-                               conseq_support = conseq_supports[selnames],
-                               count = pp[sel],
-                               antecedent_length = length(condition)))
-    }
-
-    f2 <- function(condition, sum, pp) {
-        basic_callback(condition, sum, pp)$res
-    }
-
-    f3 <- function(condition, sum, pp, pn, np, nn) {
-        bas <- basic_callback(condition, sum, pp)
-        sel <- bas$sel
-        res <- bas$res
-
-        if (length(res) <= 0) {
-            return(NULL)
-        }
-
-        res$pp <- pp[sel]
-        res$pn <- pn[sel]
-        res$np <- np[sel]
-        res$nn <- nn[sel]
-
-        res
-    }
-
-    contingency_needed_measures <- c("conviction")
-    contingency_needed <- length(intersect(measures, contingency_needed_measures)) > 0
-    f <- ifelse(contingency_table || contingency_needed, f3, f2)
-
-    res <- dig(x = x,
-               f = f,
-               condition = !!antecedent,
-               focus = !!consequent,
-               disjoint = disjoint,
-               min_length = min_length,
-               max_length = max_length,
-               min_support = min_coverage,
-               min_focus_support = min_support,
-               filter_empty_foci = TRUE,
-               t_norm = t_norm,
-               threads = threads,
-               ...)
-
-    res <- do.call(rbind, res)
-
-    if ("lift" %in% measures) {
-        res$lift <- res$support / (res$coverage * res$conseq_support)
-    }
-    if ("conviction" %in% measures) {
-        res$conviction <- res$coverage * (1 - res$conseq_support) / (res$pn / n)
-    }
-
-    if ("added_value" %in% measures) {
-        res$added_value <- res$confidence - res$conseq_support
-    }
-
-    if (!contingency_table) {
-        res$pp <- NULL
-        res$pn <- NULL
-        res$np <- NULL
-        res$nn <- NULL
-    }
-
-    as_tibble(res)
+    dig_associations(x = x,
+                     antecedent = antecedent,
+                     consequent = consequent,
+                     disjoint = disjoint,
+                     min_length = min_length,
+                     max_length = max_length,
+                     min_coverage = min_coverage,
+                     min_support = min_support,
+                     min_confidence = min_confidence,
+                     contingency_table = contingency_table,
+                     measures = measures,
+                     t_norm = t_norm,
+                     threads = threads,
+                     ...)
 }
