@@ -38,12 +38,15 @@ class LogStartEnd {
 public:
     LogStartEnd(const std::string &what)
         : what(what)
-    { start = std::chrono::steady_clock::now(); }
+    {
+        start = std::chrono::steady_clock::now();
+        Rcout << "BEGIN " << what << std::endl;
+    }
 
     ~LogStartEnd()
     {
         std::chrono::steady_clock::time_point end = std::chrono::steady_clock::now();
-        Rcout << what << ": "  <<
+        Rcout << "END " << what << ": "  <<
             (std::chrono::duration_cast<std::chrono::microseconds>(end - start).count() / 1000.0) <<
             "[ms]" << std::endl;
     }
