@@ -6,6 +6,8 @@ test_that("dig_correlations", {
                     y = rnorm(100),
                     z = rnorm(100))
     res <- dig_correlations(x = d,
+                            method = "pearson",
+                            alternative = "two.sided",
                             condition = where(is.logical),
                             xvars = where(is.numeric),
                             yvars = where(is.numeric))
@@ -13,7 +15,7 @@ test_that("dig_correlations", {
     expect_true(is_tibble(res))
     expect_equal(nrow(res), 12)
     expect_equal(colnames(res),
-                 c("condition", "support", "xvar", "yvar", "estimate", "p_value", "rows"))
+                 c("condition", "support", "xvar", "yvar", "estimate", "p_value", "method", "alternative", "rows"))
     expect_equal(res$condition,
                  c(rep("{}", 3), rep("{a}", 3), rep("{b}", 3), rep("{a,b}", 3)))
     expect_equal(res$xvar,
@@ -22,6 +24,10 @@ test_that("dig_correlations", {
                  rep(c("y", "z", "z"), 4))
     expect_equal(res$support,
                  c(rep(100, 6), rep(50, 6)) / 100)
+    expect_equal(res$method,
+                 rep("Pearson's product-moment correlation", 12))
+    expect_equal(res$alternative,
+                 rep("two.sided", 12))
     expect_equal(res$rows,
                  c(rep(100, 6), rep(50, 6)))
 })
@@ -45,7 +51,7 @@ test_that("dig_correlations with NA", {
     expect_true(is_tibble(res))
     expect_equal(nrow(res), 12)
     expect_equal(colnames(res),
-                 c("condition", "support", "xvar", "yvar", "estimate", "p_value", "rows"))
+                 c("condition", "support", "xvar", "yvar", "estimate", "p_value", "method", "alternative", "rows"))
     expect_equal(res$condition,
                  c(rep("{}", 3), rep("{a}", 3), rep("{b}", 3), rep("{a,b}", 3)))
     expect_equal(res$xvar,
@@ -54,6 +60,10 @@ test_that("dig_correlations with NA", {
                  rep(c("y", "z", "z"), 4))
     expect_equal(res$support,
                  c(rep(100, 6), rep(50, 6)) / 100)
+    expect_equal(res$method,
+                 rep("Pearson's product-moment correlation", 12))
+    expect_equal(res$alternative,
+                 rep("two.sided", 12))
     expect_equal(res$rows,
                  c(98, 99, 99,
                    98, 99, 99,
@@ -63,9 +73,9 @@ test_that("dig_correlations with NA", {
 
 
 test_that("dig_correlations iris", {
-    dcor <- dichotomize(iris, what = Species, .other = TRUE)
-    res <- dig_correlations(dcor, max_length = 0)
+    dcor <- partition(iris, Species)
 
+    res <- dig_correlations(dcor, max_length = 0)
     expect_true(is_tibble(res))
     expect_equal(nrow(res), 6)
 
@@ -73,6 +83,15 @@ test_that("dig_correlations iris", {
                             xvars = Sepal.Length:Petal.Width,
                             yvars = Sepal.Length:Petal.Width,
                             max_length = 0)
+    expect_true(is_tibble(res))
+    expect_equal(nrow(res), 6)
+
+    res <- dig_correlations(dcor,
+                            xvars = Sepal.Length:Petal.Width,
+                            yvars = Sepal.Length:Petal.Width,
+                            condition = NULL)
+    expect_true(is_tibble(res))
+    expect_equal(nrow(res), 6)
 })
 
 
@@ -81,7 +100,7 @@ test_that("errors", {
 
     expect_true(is.list(dig_correlations(d, condition = c(l))))
     expect_error(dig_correlations(d, condition = c(l, n)),
-                 "columns selected by `condition` must be logical.")
+                 "All columns selected by `condition` must be logical.")
     expect_error(dig_correlations(d, condition = c(l, s)),
-                 "columns selected by `condition` must be logical.")
+                 "All columns selected by `condition` must be logical.")
 })
